// Copyright (c) 2016, root ext. All rights reserved. Use of this source code
// is governed by a BSD-style license that can be found in the LICENSE file.

import 'dart:io';
import 'package:test/test.dart';
import '../lib/dna.dart';

void main() {

  group('base tests', () {
    int library;

    setUp(() {
      if (!Platform.isWindows){
        print("unexpected OS");
        exit(0);
      }

      library =  nLoadLibrary('kernel32.dll');
    });

    tearDown(() {
      nFreeLibrary(library);
    });

    test('library', () {
      expect(library, isNonZero);
    });

    test('empty vm', () {
      var vm = nCreateCallVM(256);
      expect(vm, isNonZero);
      nFreeCallVM(vm);
    });

    test('getpid', () {

      var method = nFindSymbol(library, 'GetCurrentProcess');
      expect(method, isNonZero);
      var vm = nCreateCallVM(256);
      var processPointer = nCall(vm, method, new String.fromCharCodes([ARG_INT]));
      nFreeCallVM(vm);

      method = nFindSymbol(library, 'GetProcessId');
      expect(method, isNonZero);
      vm = nCreateCallVM(256);
      nArgs(vm, new String.fromCharCodes([ARG_INT]), [processPointer]);
      var processId = nCall(vm, method, new String.fromCharCodes([ARG_INT]));
      nFreeCallVM(vm);

      expect(processId, isNonZero);
      expect(processId, equals(pid));
    });


  });
}
